#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   fedhf\component\communicator\__init__.py
@Time    :   2021-11-09 17:56:24
@Author  :   Bingjie Yan
@Email   :   bj.yan.pa@qq.com
@License :   Apache License 2.0
"""

from .base_communicator import BaseCommunicator
from .distributed_communicator import DistributedCommunicator